"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DataLoader = void 0;
var _utils = require("@webiny/utils");
class DataLoader {
  constructor(dataSources) {
    this.dataSources = dataSources;
  }
  async load(request) {
    const type = request.getType();
    const dataSource = this.dataSources.find(ds => ds.getType() === type);
    if (!dataSource) {
      throw new Error(`Can't find dataSource ${type}`);
    }
    const configSchema = dataSource.getConfigSchema();
    const result = await configSchema.safeParseAsync(request.getConfig());
    if (!result.success) {
      throw (0, _utils.createZodError)(result.error);
    }
    return dataSource.load(request.withConfig(result.data));
  }
}
exports.DataLoader = DataLoader;

//# sourceMappingURL=DataLoader.js.map