"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PathsParser = void 0;
var _ParsedPath = require("./ParsedPath");
class PathsParser {
  parse(paths) {
    const selection = {};

    // Sort paths to ensure parent paths come after child paths
    const sortedPaths = [...paths].sort((a, b) => b.length - a.length);
    sortedPaths.forEach(path => {
      let current = selection;
      let remainingPath = path;
      while (remainingPath) {
        const {
          key,
          fragment,
          remaining
        } = _ParsedPath.ParsedPath.create(remainingPath);
        remainingPath = remaining;
        if (!fragment) {
          // Handle regular field
          if (!remainingPath) {
            // Don't overwrite existing object with true
            if (typeof current[key] !== "object") {
              current[key] = true;
            }
          } else {
            if (!current[key] || current[key] === true) {
              current[key] = {};
            }
            current = current[key];
          }
        } else {
          // Handle fragment
          if (!current[key] || current[key] === true) {
            current[key] = {};
          }
          const fragmentContainer = current[key];
          const fragmentKey = `fragment_${fragment}`;
          if (!fragmentContainer[fragmentKey]) {
            fragmentContainer[fragmentKey] = {
              type: fragment,
              fields: {}
            };
          }
          if (remaining) {
            current = fragmentContainer[fragmentKey].fields;
          }
        }
      }
    });
    return selection;
  }
}
exports.PathsParser = PathsParser;

//# sourceMappingURL=PathsParser.js.map