"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findProvider = exports.fetchEmbed = void 0;
var _nodeFetch = _interopRequireDefault(require("node-fetch"));
var _providers = require("./providers");
const getHostname = url => {
  const match = url.match(/:\/\/(www[0-9]?\.)?(.[^/:]+)/i);
  if (match && match.length > 2 && typeof match[2] === "string" && match[2].length > 0) {
    return match[2];
  }
  return null;
};
const providers = _providers.providerList.map(item => {
  const {
    provider_name,
    provider_url,
    endpoints
  } = item;
  const endpoint = endpoints[0];
  const {
    schemes = [],
    url
  } = endpoint;
  const hostname = getHostname(url);
  const domain = hostname ? hostname.replace("www.", "") : "";
  return {
    provider_name,
    provider_url,
    schemes,
    domain,
    url
  };
}).filter(item => {
  return item.domain !== "";
});
const findProvider = url => {
  const candidates = providers.filter(provider => {
    const {
      schemes,
      domain
    } = provider;
    if (!schemes.length) {
      return url.includes(domain);
    }
    return schemes.some(scheme => {
      const reg = new RegExp(scheme.replace(/\*/g, "(.*)"), "i");
      return url.match(reg);
    });
  });
  return candidates.length > 0 ? candidates[0] : null;
};
exports.findProvider = findProvider;
const fetchEmbed = async (params, provider) => {
  const link = `${provider.url}?format=json&` + Object.keys(params).map(k => `${k}=${encodeURIComponent(params[k])}`).join("&");
  const json = await (0, _nodeFetch.default)(link).then(res => res.json());
  return {
    ...json,
    source: params
  };
};
exports.fetchEmbed = fetchEmbed;

//# sourceMappingURL=index.js.map